==> yopo-0.0.5.tar.gz: yopo-0.0.5/README.md <==
# **YOPO** (You Only Plot Once)
![](https://img.shields.io/github/license/chekoduadarsh/YOPO-You-Only-Plot-Once)
![](https://img.shields.io/github/issues/chekoduadarsh/YOPO-You-Only-Plot-Once)
![](https://img.shields.io/github/last-commit/chekoduadarsh/YOPO-You-Only-Plot-Once)


![Python](https://img.shields.io/badge/python-3670A0?style=for-the-badge&logo=python&logoColor=ffdd54)
![Plotly](https://img.shields.io/badge/Plotly-%233F4F75.svg?style=for-the-badge&logo=plotly&logoColor=white)
![Flask](https://img.shields.io/badge/flask-%23000.svg?style=for-the-badge&logo=flask&logoColor=white)

**You Only Plot Once**

YOPO is an interactive dashboard which generates various standard plots.you can create various graphs and charts with a click of a button. This tool uses Dash and Flask in backend.

# Table of contents
- [**YOPO** (You Only Plot Once)](#yopo-you-only-plot-once)
- [Table of contents](#table-of-contents)
- [Installing YOPO](#installing-yopo)
- [Usage](#usage)
- [Contribute](#contribute)
- [License](#license)

# Installing YOPO

To install from PyPi:

```shell
pip install yopo
```

To install from source:

```shell
cd <your_project>
git clone https://github.com/chekoduadarsh/YOPO-You-Only-Plot-Once.git
# or download and unzip https://github.com/AutoViML/AutoViz/archive/master.zip
# if you dont have virtualenv install from here https://packaging.python.org/en/latest/guides/installing-using-pip-and-virtual-environments/
python3 -m venv env
source env/bin/activate
git clone https://github.com/chekoduadarsh/YOPO-You-Only-Plot-Once.git
# or download and unzip https://github.com/AutoViML/AutoViz/archive/master.zip
cd yopo
python3 -m pip install .
```

# Usage

its very easy to use YOPO, u just need to pass the dataframe and it will generate the dashboard. 
![](https://raw.githubusercontent.com/chekoduadarsh/YOPO-You-Only-Plot-Once/master/media/sample_iris_code.png)

A code like this will generate multiple plots like given below.

![](https://raw.githubusercontent.com/chekoduadarsh/YOPO-You-Only-Plot-Once/master/media/sample_dataframe.png)
![](https://raw.githubusercontent.com/chekoduadarsh/YOPO-You-Only-Plot-Once/master/media/sample_histogram.png)
![](https://raw.githubusercontent.com/chekoduadarsh/YOPO-You-Only-Plot-Once/master/media/sample_scatterplot.png)



# Contribute

If you find any error or need support please raise a issue. If you think you can add a feature, or help solve a bug please raise a PR
This repo welcomes any kind of contributions pray

Feel free to adapt it criticize it and support it the way you like!!

# License

[Apache License, Version 2.0](https://github.com/chekoduadarsh/YOPO-You-Only-Plot-Once/blob/master/LICENSE.txt)

==> yopo-0.0.13.tar.gz: yopo-0.0.13/README.md <==
# **YOPO** (You Only Plot Once)
![](https://img.shields.io/github/license/chekoduadarsh/YOPO-You-Only-Plot-Once)
![](https://img.shields.io/github/issues/chekoduadarsh/YOPO-You-Only-Plot-Once)
![](https://img.shields.io/github/last-commit/chekoduadarsh/YOPO-You-Only-Plot-Once)


![Python](https://img.shields.io/badge/python-3670A0?style=for-the-badge&logo=python&logoColor=ffdd54)
![Plotly](https://img.shields.io/badge/Plotly-%233F4F75.svg?style=for-the-badge&logo=plotly&logoColor=white)
![Flask](https://img.shields.io/badge/flask-%23000.svg?style=for-the-badge&logo=flask&logoColor=white)

**You Only Plot Once**

YOPO is an **~0 Code** interactive dashboard which generates various standard plots.you can create various graphs and charts with a click of a button. This tool uses Dash and Flask in backend.


[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/chekoduadarsh/YOPO-You-Only-Plot-Once/blob/master/example.ipynb)


# Table of contents
- [**YOPO** (You Only Plot Once)](#yopo-you-only-plot-once)
- [Table of contents](#table-of-contents)
- [Installing YOPO](#installing-yopo)
- [Usage](#usage)
- [Contribute](#contribute)
- [License](#license)

# Installing YOPO

To install from PyPi:

```shell
pip install yopo
```

To install from source:

```shell
cd <your_project>
git clone https://github.com/chekoduadarsh/YOPO-You-Only-Plot-Once.git
# or download and unzip https://github.com/AutoViML/AutoViz/archive/master.zip
# if you dont have virtualenv install from here https://packaging.python.org/en/latest/guides/installing-using-pip-and-virtual-environments/
python3 -m venv env
source env/bin/activate
git clone https://github.com/chekoduadarsh/YOPO-You-Only-Plot-Once.git
# or download and unzip https://github.com/AutoViML/AutoViz/archive/master.zip
cd yopo
python3 -m pip install .
```

# Usage

its very easy to use YOPO, u just need to pass the dataframe and it will generate the dashboard. 
![](https://raw.githubusercontent.com/chekoduadarsh/YOPO-You-Only-Plot-Once/master/media/sample_iris_code.png)

A code like this will generate multiple plots like given below.

![](https://raw.githubusercontent.com/chekoduadarsh/YOPO-You-Only-Plot-Once/master/media/sample_dataframe.png)
![](https://raw.githubusercontent.com/chekoduadarsh/YOPO-You-Only-Plot-Once/master/media/sample_histogram.png)
![](https://raw.githubusercontent.com/chekoduadarsh/YOPO-You-Only-Plot-Once/master/media/sample_scatterplot.png)
![](https://raw.githubusercontent.com/chekoduadarsh/YOPO-You-Only-Plot-Once/master/media/sample_custom.png)



# Contribute

If you find any error or need support please raise a issue. If you think you can add a feature, or help solve a bug please raise a PR
This repo welcomes any kind of contributions pray

Feel free to adapt it criticize it and support it the way you like!!

# License

[Apache License, Version 2.0](https://github.com/chekoduadarsh/YOPO-You-Only-Plot-Once/blob/master/LICENSE.txt)
